"""Testing utilities.

Test creation, validation, naming conventions, and bidirectional mapping between
source and test objects.

Modules:
    convention: Test naming conventions and object mapping
"""
