"""Constants used across pyrig modules."""

STANDARD_DEV_DEPS: list[str] = ["pyrig-dev"]
"""Standard development dependencies for pyrig-based projects.

The `pyrig-dev` meta-package includes testing, type checking, linting,
documentation, build tools and some other dev dependencies.
"""
